@@ -56,6 +56,8 @@ static int num_plugins_used = 0;
 static int selected_plugin = -1;
 static int current_track = -1;
 static enum music_usage current_usage;
+static bool switching_usage = FALSE;
+static bool let_single_track_play = FALSE;
 
 static struct mfcb_data
 {
@@ -371,10 +373,22 @@ static void music_finished_callback(void)
 {
   bool usage_enabled = TRUE;
 
+  if (switching_usage) {
+    switching_usage = FALSE;
+
+    return;
+  }
+
+  if (let_single_track_play) {
+    /* This call is style music ending before single track plays.
+     * Do not restart style music now.
+     * Make sure style music restarts when single track itself finishes. */
+    let_single_track_play = FALSE;
+
+    return;
+  }
+
   switch (current_usage) {
-  case MU_SINGLE:
-    usage_enabled = FALSE;
-    break;
   case MU_MENU:
     usage_enabled = gui_options.sound_enable_menu_music;
     break;
@@ -443,15 +457,21 @@ static int audio_play_tag(struct section_file *sfile,
           /* Exclude track was skipped earlier, include it to track number to return */
           ret++;
         }
-        if (repeat) {
-          if (!keep_old_style) {
-            mfcb.sfile = sfile;
-            mfcb.tag = tag;
-          }
-          cb = music_finished_callback;
-        }
       }
     }
+
+    if (repeat) {
+      if (!keep_old_style) {
+        mfcb.sfile = sfile;
+        mfcb.tag = tag;
+      }
+
+      /* Callback is needed even when there's no alternative tracks -
+       * we may be running single track now, and want to switch
+       * (by the callback) back to style music when it ends. */
+      cb = music_finished_callback;
+    }
+
     if (NULL == soundfile) {
       log_verbose("No sound file for tag %s", tag);
     } else {
@@ -547,7 +567,14 @@ void audio_play_music(const char *const tag, char *const alt_tag,
 **************************************************************************/
 void audio_play_track(const char *const tag, char *const alt_tag)
 {
-  current_usage = MU_SINGLE;
+  if (current_track >= 0) {
+    /* Only set let_single_track_play when there's music playing that will
+     * result in calling the music_finished_callback */
+    let_single_track_play = TRUE;
+
+    /* Stop old music. */
+    audio_stop();
+  }
 
   real_audio_play_music(tag, alt_tag, TRUE);
 }
@@ -565,11 +592,12 @@ void audio_stop(void)
 **************************************************************************/
 void audio_stop_usage(void)
 {
+  switching_usage = TRUE;
   plugins[selected_plugin].stop();
 }
 
 /**************************************************************************
-  Stop looping sound. Music should die down in a few seconds.
+  Get sound volume currently in use.
 **************************************************************************/
 double audio_get_volume(void)
 {
@@ -577,7 +605,7 @@ double audio_get_volume(void)
 }
 
 /**************************************************************************
-  Stop looping sound. Music should die down in a few seconds.
+  Set sound volume to use.
 **************************************************************************/
 void audio_set_volume(double volume)
 {
