@@ -63,6 +63,13 @@ bool has_zoom_support(void)
   return TRUE;
 }
 
+/****************************************************************************
+  Initialize canvas as mapview.
+****************************************************************************/
+void canvas_mapview_init(struct canvas *store)
+{
+}
+
 /****************************************************************************
   Copies an area from the source canvas to the destination canvas.
 ****************************************************************************/
