@@ -36,7 +36,7 @@
 #include "client_main.h"
 #include "options.h"
 
-/* client/gui-gtk-2.0 */
+/* client/gui-gtk-3.22 */
 #include "gui_main.h"
 #include "gui_stuff.h"
 #include "mapview.h"
@@ -168,21 +168,20 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
 {
   struct intel_dialog *pdialog;
 
-  GtkWidget *shell, *notebook, *label, *sw, *view, *table, *alignment;
+  GtkWidget *shell, *notebook, *label, *sw, *view, *table;
   GtkCellRenderer *rend;
   GtkTreeViewColumn *col;
-
   int i;
- 
+
   pdialog = fc_malloc(sizeof(*pdialog));
   pdialog->pplayer = p;
- 
+
   shell = gtk_dialog_new_with_buttons(NULL,
-      NULL,
-      0,
-      GTK_STOCK_CLOSE,
-      GTK_RESPONSE_CLOSE,
-      NULL);
+                                      NULL,
+                                      0,
+                                      _("_Close"),
+                                      GTK_RESPONSE_CLOSE,
+                                      NULL);
   pdialog->shell = shell;
   gtk_window_set_default_size(GTK_WINDOW(shell), 350, 350);
   setup_dialog(shell, toplevel);
@@ -195,37 +194,33 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
 
   notebook = gtk_notebook_new();
   gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_BOTTOM);
-  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(shell)->vbox), notebook);
+  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(shell))), notebook);
  
   /* overview tab. */
-  table = gtk_table_new(ARRAY_SIZE(table_text), 2, FALSE);
+  table = gtk_grid_new();
+  g_object_set(table, "margin", 6, NULL);
 
-  gtk_table_set_row_spacings(GTK_TABLE(table), 2);
-  gtk_table_set_col_spacings(GTK_TABLE(table), 12);
-
-  alignment = gtk_alignment_new(0.0, 0.0, 0.0, 0.0);
-  gtk_container_set_border_width(GTK_CONTAINER(alignment), 6);
-  gtk_container_add(GTK_CONTAINER(alignment), table);
+  gtk_grid_set_row_spacing(GTK_GRID(table), 2);
+  gtk_grid_set_column_spacing(GTK_GRID(table), 12);
 
   /* TRANS: Overview tab of foreign intelligence report dialog */
   label = gtk_label_new_with_mnemonic(_("_Overview"));
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), alignment, label);
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table, label);
 
   for (i = 0; i < ARRAY_SIZE(table_text); i++) {
     if (table_text[i]) {
       label = gtk_label_new(_(table_text[i]));
-      gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-      gtk_table_attach(GTK_TABLE(table), label,
-	  0, 1, i, i+1, GTK_FILL, GTK_FILL|GTK_EXPAND, 0, 0);
+      gtk_widget_set_halign(label, GTK_ALIGN_START);
+      gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+      gtk_grid_attach(GTK_GRID(table), label, 0, i, 1, 1);
 
       label = gtk_label_new(NULL);
       pdialog->table_labels[i] = label;
-      gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-      gtk_table_attach(GTK_TABLE(table), label,
-	  1, 2, i, i+1, GTK_FILL, GTK_FILL|GTK_EXPAND, 0, 0);
+      gtk_widget_set_halign(label, GTK_ALIGN_START);
+      gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+      gtk_grid_attach(GTK_GRID(table), label, 1, i, 1, 1);
     } else {
       pdialog->table_labels[i] = NULL;
-      gtk_table_set_row_spacing(GTK_TABLE(table), i, 12);
     }
   }
 
@@ -233,6 +228,9 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   pdialog->diplstates = gtk_tree_store_new(1, G_TYPE_STRING);
 
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pdialog->diplstates));
+  g_object_set(view, "margin", 6, NULL);
+  gtk_widget_set_hexpand(view, TRUE);
+  gtk_widget_set_vexpand(view, TRUE);
   g_object_unref(pdialog->diplstates);
   gtk_container_set_border_width(GTK_CONTAINER(view), 6);
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), FALSE);
@@ -252,12 +250,8 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 	GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-  alignment = gtk_alignment_new(0.0, 0.0, 1.0, 1.0);
-  gtk_container_set_border_width(GTK_CONTAINER(alignment), 6);
-  gtk_container_add(GTK_CONTAINER(alignment), sw);
-
   label = gtk_label_new_with_mnemonic(_("_Diplomacy"));
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), alignment, label);
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sw, label);
 
   /* techs tab. */
   pdialog->techs = gtk_list_store_new(2, G_TYPE_BOOLEAN, G_TYPE_STRING);
@@ -265,6 +259,9 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
       1, GTK_SORT_ASCENDING);
 
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pdialog->techs));
+  g_object_set(view, "margin", 6, NULL);
+  gtk_widget_set_hexpand(view, TRUE);
+  gtk_widget_set_vexpand(view, TRUE);
   g_object_unref(pdialog->techs);
   gtk_container_set_border_width(GTK_CONTAINER(view), 6);
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), FALSE);
@@ -287,14 +284,10 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 	GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-  alignment = gtk_alignment_new(0.0, 0.0, 1.0, 1.0);
-  gtk_container_set_border_width(GTK_CONTAINER(alignment), 6);
-  gtk_container_add(GTK_CONTAINER(alignment), sw);
-
   label = gtk_label_new_with_mnemonic(_("_Techs"));
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), alignment, label);
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sw, label);
 
-  gtk_widget_show_all(GTK_DIALOG(shell)->vbox);
+  gtk_widget_show_all(gtk_dialog_get_content_area(GTK_DIALOG(shell)));
 
   dialog_list_prepend(dialog_list, pdialog);
 
@@ -302,7 +295,7 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
 }
 
 /****************************************************************************
-  Update the intelligence dialog for the given player.  This is called by
+  Update the intelligence dialog for the given player. This is called by
   the core client code when that player's information changes.
 ****************************************************************************/
 void update_intel_dialog(struct player *p)
@@ -313,6 +306,10 @@ void update_intel_dialog(struct player *p)
     const struct research *mresearch, *presearch;
     GtkTreeIter diplstates[DS_LAST];
     int i;
+    bool global_observer = client_is_global_observer();
+    struct player *me = client_player();
+    bool embassy_knowledge = global_observer || player_has_embassy(me, p);
+    bool trade_knowledge = global_observer || p == me || could_intel_with_player(me, p);
 
     /* window title. */
     gchar *title = g_strdup_printf(_("Foreign Intelligence: %s Empire"),
@@ -335,13 +332,13 @@ void update_intel_dialog(struct player *p)
       diplstates[i] = it;
     }
 
-    players_iterate_alive(other) {
+    players_iterate(other) {
       const struct player_diplstate *state;
       GtkTreeIter it;
       GValue v = { 0, };
 
-      if (other == p) {
-        continue;
+      if (other == p || !other->is_alive) {
+	continue;
       }
       state = player_diplstate_get(p, other);
       gtk_tree_store_append(pdialog->diplstates, &it,
@@ -350,7 +347,7 @@ void update_intel_dialog(struct player *p)
       g_value_set_static_string(&v, player_name(other));
       gtk_tree_store_set_value(pdialog->diplstates, &it, 0, &v);
       g_value_unset(&v);
-    } players_iterate_alive_end;
+    } players_iterate_end;
 
     /* techs tab. */
     gtk_list_store_clear(pdialog->techs);
@@ -385,24 +382,44 @@ void update_intel_dialog(struct player *p)
           buf = g_strdup(tbuf);
           break;
         case LABEL_GOVERNMENT:
-          buf = g_strdup(government_name_for_player(p));
+          if (trade_knowledge) {
+            buf = g_strdup(government_name_for_player(p));
+          } else {
+            buf = g_strdup(_("(Unknown)"));
+          }
           break;
         case LABEL_CAPITAL:
           pcity = player_capital(p);
           /* TRANS: "unknown" location */
-          buf = g_strdup((!pcity) ? _("(unknown)") : city_name_get(pcity));
+          buf = g_strdup((!pcity) ? _("(Unknown)") : city_name_get(pcity));
           break;
         case LABEL_GOLD:
-          buf = g_strdup_printf("%d", p->economic.gold);
+          if (trade_knowledge) {
+            buf = g_strdup_printf("%d", p->economic.gold);
+          } else {
+            buf = g_strdup(_("(Unknown)"));
+          }
           break;
         case LABEL_TAX:
-          buf = g_strdup_printf("%d%%", p->economic.tax);
+          if (embassy_knowledge) {
+            buf = g_strdup_printf("%d%%", p->economic.tax);
+          } else {
+            buf = g_strdup(_("(Unknown)"));
+          }
           break;
         case LABEL_SCIENCE:
-          buf = g_strdup_printf("%d%%", p->economic.science);
+          if (embassy_knowledge) {
+            buf = g_strdup_printf("%d%%", p->economic.science);
+          } else {
+            buf = g_strdup(_("(Unknown)"));
+          }
           break;
         case LABEL_LUXURY:
-          buf = g_strdup_printf("%d%%", p->economic.luxury);
+          if (embassy_knowledge) {
+            buf = g_strdup_printf("%d%%", p->economic.luxury);
+          } else {
+            buf = g_strdup(_("(Unknown)"));
+          }
           break;
         case LABEL_RESEARCHING:
           {
@@ -414,8 +431,12 @@ void update_intel_dialog(struct player *p)
               buf = g_strdup(_("(Unknown)"));
               break;
             case A_UNSET:
-              /* TRANS: missing value */
-              buf = g_strdup(_("(none)"));
+              if (embassy_knowledge) {
+                /* TRANS: missing value */
+                buf = g_strdup(_("(none)"));
+              } else {
+                buf = g_strdup(_("(Unknown)"));
+              }
               break;
             default:
               buf = g_strdup_printf("%s(%d/%d)",
