@@ -543,21 +543,29 @@ void redraw_widget_info_label(SDL_Rect *rect)
 }
 
 /**************************************************************************
-  Find ID in Widget's List ('pGUI_List') and return pointer to this
+  Find ID in widgets list ('gui_list') and return pointer to this
   Widgets.
 **************************************************************************/
-struct widget *get_widget_pointer_from_id(const struct widget *pGUI_List,
-				       Uint16 ID, enum scan_direction direction)
+struct widget *get_widget_pointer_from_id(const struct widget *gui_list,
+                                          Uint16 id,
+                                          enum scan_direction direction)
 {
-  while (pGUI_List) {
-    if (pGUI_List->ID == ID) {
-      return (struct widget *) pGUI_List;
+  if (direction == SCAN_FORWARD) {
+    while (gui_list) {
+      if (gui_list->ID == id) {
+        return (struct widget *) gui_list;
+      }
+      gui_list = gui_list->next;
+    }
+  } else {
+    while (gui_list) {
+      if (gui_list->ID == id) {
+        return (struct widget *) gui_list;
+      }
+      gui_list = gui_list->prev;
     }
-    if (direction == SCAN_FORWARD)
-    pGUI_List = pGUI_List->next;
-    else
-      pGUI_List = pGUI_List->prev;  
   }
+
   return NULL;
 }
 
