@@ -18,10 +18,13 @@ extern "C" {
 #endif /* __cplusplus */
 
 #include "fc_types.h"
+#include "map.h"
 #include "tile.h"
 
 #define SINGLE_MOVE     (terrain_control.move_fragments)
 #define MOVE_COST_IGTER (terrain_control.igter_cost)
+/* packets.def MOVEFRAGS */
+#define MAX_MOVE_FRAGS  65535
 
 struct unit_type;
 struct terrain;
